@@ -91,7 +91,7 @@ class EndpointGroup(Generic[T]):
     def _get_entity_type(self):
         return next(base.__args__[0] for base in self.__class__.__orig_bases__ if len(base.__args__)==1)
 
-    def _call_endpoint(self,method,endpoint_path,query_params=None,body=None, entityClass=T):
+    def _call_endpoint(self,method,endpoint_path,query_params=None,body=None, entityClass=T, ignore_err_status_codes=None):
         request_url = self._url_for_path(endpoint_path)
 
         if dataclasses.is_dataclass(body):
@@ -126,6 +126,9 @@ class EndpointGroup(Generic[T]):
             else:
                 return entityClass(response.content)
         else:
+            if response.status_code==ignore_err_status_codes \
+                or isinstance(ignore_err_status_codes,list) and (response.status_code in ignore_err_status_codes):
+                return None
             raise Exception(f"Error response from server: {response.status_code}: {response.text}")
 
 
@@ -325,7 +328,7 @@ class DocumentsEndpointGroup(EndpointGroup[data_model.TextDocument]):
 
     def query(self,
             project_id: str, 
-            query:Union[DocumentQueryFilter,Or],
+            query:Union[DocumentQueryFilter,Or, Dict],
             order_by:str = None,
             skip:int = 0,
             take:int=50
@@ -334,7 +337,7 @@ class DocumentsEndpointGroup(EndpointGroup[data_model.TextDocument]):
 
         Args:
             project_id (str): Uuid of project
-            query (Union[DocumentQueryFilter,Or]): Where query to match the documents
+            query (Union[DocumentQueryFilter,Or,Dict]): Where query to match the documents
             order_by (str, optional): Sort by field. Defaults to None.
             skip (int, optional): paging - skip. Defaults to 0.
             take (int, optional): paging - take. Defaults to 50.
@@ -514,7 +517,7 @@ class SimilarityLinkEndpointGroup(EndpointGroup[Tuple[dict,dict]]):
             fetch_all=True,
             skip:int = 0,
             take:int = 50
-    ) -> Union[List[Tuple[dict,dict]],Iterator[Tuple[dict,dict]]]:
+    ) -> List[Tuple[dict,dict]]:
         """query the similarity links
         
         Note: Be aware that links are both sided so eventualy each link is efectively returned twice, with swaped items in the resulting tuple
@@ -532,24 +535,7 @@ class SimilarityLinkEndpointGroup(EndpointGroup[Tuple[dict,dict]]):
             Union[List[Tuple[dict,dict]],Iterator[Tuple[dict,dict]]]: return list or itterator (if fetch_all=False) of tuples of two items (left, right side of the link)
         """
 
-       
-        print("test")
-        if fetch_all:
-            result = []
-            page=1
-            page_size=500
-
-            while True:
-                previous_len=len(result)
-                for item in self.query(project_id,link_type, select, query, fetch_all=False, skip=page*page_size, take=page_size):
-                    result.append(item)
-
-                if len(result)==previous_len: #if not more data was fetched
-                    return result
-                else:
-                    page=page+1
-
-        else:
+        def fetch_data():
             responseData = self._call_endpoint("POST", f"/projects/{project_id}/doc/similar/links/{link_type}/query", 
                 body=query, 
                 query_params={ 
@@ -560,12 +546,29 @@ class SimilarityLinkEndpointGroup(EndpointGroup[Tuple[dict,dict]]):
                 )
             for rec in responseData:
                 yield tuple(rec) 
+       
+        if fetch_all:
+            result = []
+            page=1
+            page_size=500
+
+            while True:
+                previous_len=len(result)
+                for item in self.query(project_id,link_type, select, query, fetch_all=False, skip=(page-1)*page_size, take=page_size):
+                    result.append(item)
+
+                if len(result)==previous_len: #if not more data was fetched
+                    return result
+                else:
+                    page=page+1
+
+        else:
+            return list(fetch_data())
 
 class ModelsEndpointGroup(EndpointGroup[data_model.ModelInfo]):
     def __init__(self, client: Client) -> None:
         super().__init__(client)     
 
-   
 
     def get_info(self, model_name:str, project_id:str=None)  -> data_model.ModelInfo:
         """Get model details
@@ -578,13 +581,15 @@ class ModelsEndpointGroup(EndpointGroup[data_model.ModelInfo]):
             data_model.ModelInfo: _description_
         """
         
-        if project_id and "/" not in model_name:
-            return self._call_endpoint("GET", f"projects/{project_id}/models/{model_name}")
-        else:
-            if "/" in model_name:
-                return self._call_endpoint("GET", f"models/info/{model_name}")
+        
+        if "/" in model_name or project_id:
+            if project_id:
+                query={"project_id":project_id}
             else:
-                raise Exception("if project_id is not set, model_name must be in this pattern: '{project_name}/{model_name}'")
+                query=None
+            return self._call_endpoint("GET", f"models/info/{model_name}", query_params=query)
+        else:
+            raise Exception("if project_id is not set, model_name must be in this pattern: '{project_name}/{model_name}'")
 
     def delete(self, project_id:str,model_name_or_id:str)-> None: 
         """Delete model
@@ -611,6 +616,8 @@ class ModelsEndpointGroup(EndpointGroup[data_model.ModelInfo]):
         if not target_path:
             target_path= os.getcwd()
         file_urls = self._call_endpoint("GET", f"/projects/{project_id}/models/download-urls",query_params={"model_name_or_id":model_name_or_id}, entityClass=dict)
+        if not file_urls:
+            raise Exception("There seams to be no files for this model!")
         for fileUrl in file_urls:
             response = requests.get(fileUrl["url"], stream=True)
             (path,file_name) = os.path.split(fileUrl["file"])
